@@ -471,9 +471,9 @@ class Move(Workflow, ModelSQL, ModelView):
             return True
         if from_type in {'storage', 'drop'} and to_type == 'customer':
             return True
-        if from_type == 'storage' and to_type == 'supplier':
+        if from_type in {'storage', 'drop'} and to_type == 'supplier':
             return True
-        if from_type == 'customer' and to_type == 'storage':
+        if from_type == 'customer' and to_type == {'storage', 'drop'}:
             return True
         return False
 
@@ -482,7 +482,9 @@ class Move(Workflow, ModelSQL, ModelView):
         from_type = self.from_location.type if self.from_location else None
         to_type = self.to_location.type if self.to_location else None
         return ((from_type != 'storage' and to_type == 'storage')
-            or (from_type == 'storage' and to_type != 'storage'))
+            or (from_type == 'storage' and to_type != 'storage')
+            or (from_type != 'drop' and to_type == 'drop')
+            or (from_type == 'drop' and to_type != 'drop'))
 
     @fields.depends('from_location', 'quantity')
     def on_change_with_assignation_required(self, name=None):
